.. km3io documentation master file, created by
   sphinx-quickstart on Fri Nov  1 14:27:13 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   changelog

   autoapi/index
   autoapi/km3io/aanet/index
   autoapi/km3io/jpp/index

   Code Coverage <http://km3py.pages.km3net.de/km3io/coverage>
   Source (Git) <https://git.km3net.de/km3py/km3io.git>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
